@@ -1,7 +1,9 @@
 package Bencher;
 
-our $DATE = '2020-08-16'; # DATE
-our $VERSION = '1.051'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-13'; # DATE
+our $DIST = 'Bencher'; # DIST
+our $VERSION = '1.052'; # VERSION
 
 1;
 # ABSTRACT: A benchmark framework
@@ -18,7 +20,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 1.051 of Bencher (from Perl distribution Bencher), released on 2020-08-16.
+This document describes version 1.052 of Bencher (from Perl distribution Bencher), released on 2021-08-13.
 
 =head1 SYNOPSIS
 
@@ -684,13 +686,32 @@ L<Benchmark>, L<Benchmark::Dumb> (L<Dumbbench>)
 
 C<Bencher::Scenario::*> for examples of scenarios.
 
+An article about Bencher written in 2016, L<https://perladvent.org/2016/2016-12-03.html>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
